import 'package:flutter/material.dart';
import 'room_search_list_page.dart';

// 설정
import '../../config/config.dart';

// 광고
import 'package:google_mobile_ads/google_mobile_ads.dart';  // ★ AdMob 패키지

class RoomSearchHomePage extends StatefulWidget {
  const RoomSearchHomePage({Key? key}) : super(key: key);

  @override
  State<RoomSearchHomePage> createState() => _RoomSearchHomePageState();
}

class _RoomSearchHomePageState extends State<RoomSearchHomePage> {
  BannerAd? _bannerAd;
  bool _isBannerReady = false; // 광고 로드 완료 여부
  String adUnitId = Config.testAdUnitId;

  @override
  void initState() {
    super.initState();

    // (C) 배너 광고 초기화
    _initBannerAd();
  }

  @override
  void dispose() {
    _bannerAd?.dispose();
    super.dispose();
  }

  /// 배너 광고 초기화
  void _initBannerAd() {
    _bannerAd = BannerAd(
      size: AdSize.banner, // 일반 배너 사이즈
      // adUnitId: 'ca-app-pub-3940256099942544/6300978111' (테스트용)
      adUnitId: adUnitId, // 실제/테스트 배너 광고 단위 ID
      listener: BannerAdListener(
        onAdLoaded: (Ad ad) {
          setState(() => _isBannerReady = true);
          debugPrint('배너 광고 로드 완료');
        },
        onAdFailedToLoad: (Ad ad, LoadAdError err) {
          debugPrint('배너 광고 로드 실패: $err');
          ad.dispose();
        },
      ),
      request: const AdRequest(),
    );

    // load() 호출로 광고 요청
    _bannerAd?.load();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,

      appBar: AppBar(
        backgroundColor: Colors.black,
        elevation: 0,
        title: const Text('방 검색', style: TextStyle(color: Colors.white)),
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
          onPressed: () => Navigator.pop(context),
        ),
      ),

      // 화면 하단 광고 영역
      bottomNavigationBar:  _isBannerReady && _bannerAd != null
        ? Container(
            color: Colors.white,
            width: _bannerAd!.size.width.toDouble(),
            height: _bannerAd!.size.height.toDouble(),
            child: AdWidget(ad: _bannerAd!),
          )
        : SizedBox.shrink(), // 로딩 전엔 빈 공간 or 원하는 위젯

      // 본문: 중앙에 3개 버튼 (대기중 / 진행중 / 종료)
      body: Center(
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            _buildSearchStatusButton(context, label: '대기중', status: 'WAIT'),
            const SizedBox(width: 16),
            _buildSearchStatusButton(context, label: '진행중', status: 'RUNNING'),
            const SizedBox(width: 16),
            _buildSearchStatusButton(context, label: '종료', status: 'FINISH'),
          ],
        ),
      ),
    );
  }

  /// 동일한 크기로 버튼
  Widget _buildSearchStatusButton(
    BuildContext context, {
    required String label,
    required String status,
  }) {
    return SizedBox(
      width: 100,
      height: 100,
      child: ElevatedButton(
        onPressed: () {
          // RoomSearchListPage로 이동하며, roomStatus 전달
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (_) => RoomSearchListPage(roomStatus: status),
            ),
          );
        },
        style: ElevatedButton.styleFrom(
          backgroundColor: Colors.white,
          foregroundColor: Colors.black,
          side: const BorderSide(color: Colors.black, width: 1),
          shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(12)),
          padding: EdgeInsets.zero,
        ),
        child: Text(label, style: const TextStyle(color: Colors.black)),
      ),
    );
  }
}
